summaryrefslogtreecommitdiffstats
path: root/keyboards/planck/keymaps/jeebak
diff options
context:
space:
mode:
authorJeeBak Kim <jeebak.kim@gmail.com>2016-07-30 21:50:13 +0200
committerJeeBak Kim <jeebak.kim@gmail.com>2016-07-30 21:52:51 +0200
commita2ed7ce795d85f48e5c16128d767f27f19835626 (patch)
treedb3fcb330ed412190bb9d31c36117ec692617981 /keyboards/planck/keymaps/jeebak
parentdb8ad8204e66e3c00a74e0efed0b16b5e4a04500 (diff)
downloadqmk_firmware-a2ed7ce795d85f48e5c16128d767f27f19835626.tar.gz
qmk_firmware-a2ed7ce795d85f48e5c16128d767f27f19835626.tar.xz
Add additional shortcut keymaps to TOUCHCURSOR layer
Diffstat (limited to 'keyboards/planck/keymaps/jeebak')
-rw-r--r--keyboards/planck/keymaps/jeebak/keymap.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/keyboards/planck/keymaps/jeebak/keymap.c b/keyboards/planck/keymaps/jeebak/keymap.c
index 3d6523b1e..ec142ecbb 100644
--- a/keyboards/planck/keymaps/jeebak/keymap.c
+++ b/keyboards/planck/keymaps/jeebak/keymap.c
@@ -142,18 +142,21 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* ,-----------------------------------------------------------------------------------.
* | | | |Shift | GUI | ~ |Insert| Home | Up | End | Bksp | |
* |------+------+------+------+------+-------------+------+------+------+------+------|
* | | Alt |Space | | | | PgUp | Left | Down |Right | | |
* |------+------+------+------+------+------|------+------+------+------+------+------|
- * | | | | | | ` | PgDn | Del | | | | |
+ * | | Undo | Cut | Copy |Paste | ` | PgDn | Del | | | | |
* |------+------+------+------+------+------+------+------+------+------+------+------|
* | | | | | | | | | | | |
* `-----------------------------------------------------------------------------------'
+ *
+ * The KC_UNDO, KC_CUT, KC_COPY, KC_PASTE, KC_FIND, and KC_AGAIN keycodes don't
+ * seem to work on Mac. Presumably they'll work under Windows.
*/
[_TOUCHCURSOR] = {
{_______, _______, _______, KC_LSFT, KC_LGUI, KC_TILD, KC_INS, KC_HOME, KC_UP, KC_END, KC_BSPC, _______},
- {_______, KC_LALT, KC_SPC, _______, _______, _______, KC_PGUP, KC_LEFT, KC_DOWN, KC_RGHT, _______, _______},
- {_______, _______, _______, _______, _______, KC_GRV, KC_PGDN, KC_DEL, _______, _______, _______, _______},
+ {_______, KC_LALT, KC_SPC, _______, KC_FIND,KC_AGAIN, KC_PGUP, KC_LEFT, KC_DOWN, KC_RGHT, _______, _______},
+ {_______, KC_UNDO, KC_CUT, KC_COPY, KC_PASTE,KC_GRV, KC_PGDN, KC_DEL, _______, _______, _______, _______},
{_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______}
},
@@ -142,18 +142,21 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | | | |Shift | GUI | ~ |Insert| Home | Up | End | Bksp | |
* |------+------+------+------+------+-------------+------+------+------+------+------|
- * | | Alt |Space | | | | PgUp | Left | Down |Right | | |
+ * | | Alt |Space | | Find |Again | PgUp | Left | Down |Right | | |
* |------+------+------+------+------+------|------+------+------+------+------+------|